@@ -44,21 +44,8 @@ class StateMessage(Message):
     attr_list = ['value']
 
 
-def to_json(message):
-    m = vars(message)
-    if isinstance(message, RecordMessage):
-        m['type'] = 'RECORD'
-    elif isinstance(message, SchemaMessage):
-        m['type'] = 'SCHEMA'
-    elif isinstance(message, StateMessage):
-        m['type'] = 'STATE'
-    else:
-        raise Exception('Unrecognized message {}'.format(message))
-    return json.dumps(m)
-
-
 def _write_message(message):
-    sys.stdout.write(to_json(message) + '\n')
+    sys.stdout.write(message.tojson() + '\n')
     sys.stdout.flush()
 
 
@@ -105,7 +92,7 @@ def write_state(value):
 
     >>> write_state({'last_updated_at': '2017-02-14T09:21:00'})
     """
-    _write_message(StateMessage(value))
+    _write_message(StateMessage(value=value))
 
 
 def _required_key(msg, k):
